#
# stake-ground-cor.R, 14 Apr 13

library("igraph")

get_stake_list=function(graph_list)
{
# Sort by centrality value.
# Column names are the names of the nodes.
return(names(sort(graph_list, decreasing=TRUE)))
}


ground_network_cor=function(node_list)
{
# Remove any grounded names not in network_list
t_gr=subset(ground_ranking,
               subset=(ground_ranking$Stakeholder %in% names(node_list)))
# recalculate rank
t_gr$Role.Rank=rank(t_gr$Role.Rank, ties="average")

# Make sure lists are the same length
t=node_list[t_gr$Stakeholder]
# Higher is better, convert to rank order
node_rank=rank(max(t)-t, ties="average")

cor.test(t_gr$Role.Rank, node_rank, method="spearman")
}


node_metric_cor=function(stake_graph, stake_priority)
{
# Betweenness centrality
# Load centrality: not supported by igraph
# Closeness centrality
# Eigenvector centrality (not used in paper)
# In-degree centrality
# Out-degree centrality
# PageRank

between_list=betweenness(stake_graph, directed=TRUE, weights=stake_priority)
t=ground_network_cor(between_list)

metric_cor=c(betweenness=t$estimate)

# between_list=get_stake_list(between_list)

closeness_list=closeness(stake_graph, weights=stake_priority)
t=ground_network_cor(closeness_list)
metric_cor=c(metric_cor, closeness=t$estimate)

# closeness_list=get_stake_list(closeness_list)

degree_in_list=degree(stake_graph, mode="in")
t=ground_network_cor(degree_in_list)
metric_cor=c(metric_cor, degree_in=t$estimate)

# degree_in_list=get_stake_list(degree_in_list)

degree_out_list=degree(stake_graph, mode="out")
t=ground_network_cor(degree_out_list)
metric_cor=c(metric_cor, degree_out=t$estimate)

# degree_out_list=get_stake_list(degree_out_list)

evcent_list=evcent(stake_graph, directed=TRUE, weights=stake_priority)
t=ground_network_cor(evcent_list$vector)
metric_cor=c(metric_cor, evcent=t$estimate)


pagerank_list=page.rank(stake_graph, weights=stake_priority)
t=ground_network_cor(pagerank_list$vector)
metric_cor=c(metric_cor, pagerank=t$estimate)

return(metric_cor)
}


# Role Rank,Stakeholder Role,Stakeholder Rank,Stakeholder
# 1,Security and Access Systems,1,Mike Dawson
ground_stake=read.csv("/usr1/rbook/examples/projects/requirements/ground-stake.csv", stringsAsFactors=FALSE)

# Some stakeholders have equal rank
ground_ranking=subset(ground_stake, Stakeholder.Rank < 2)

# Source	Stakeholder	Priority
# Aaron Toms	Andy Hicks	10
closed_rec=read.csv("/usr1/rbook/examples/projects/requirements/ClosedR.txt",
			sep="\t", stringAsFactors=FALSE)
open_rec=read.csv("/usr1/rbook/examples/projects/requirements/OpenR.txt",
			sep="\t", stringAsFactors=FALSE)

closed_graph=graph.data.frame(closed_rec)
open_graph=graph.data.frame(open_rec)

open_cor=node_metric_cor(open_graph, open_rec$Priority)
closed_cor=node_metric_cor(closed_graph, closed_rec$Priority)

